@@ -9,13 +9,20 @@ parse_date <- function(x, format="", tz="UTC"){
   if(is.factor(x))
     x <-  as.character(x)
 
-  if(any(c("POSIXct","numeric") %in% class(x)))
+  if(any(c("Date") %in% class(x))){
     return(x)
+  }
+  if(c("POSIXct") %in% class(x))
+    return(as.Date(x))
+
+
+
   if(is.character(x)){
 
     out <- readr::parse_date(x, format=format, locale = readr::locale(tz = tz))
 
     readr::stop_for_problems(out)
+
     return(out)
   }
   stop("Unexpected type for x")
